stafftools.get_first_staff_in_improper_parentage_of_component
=============================================================

.. autofunction:: abjad.tools.stafftools.get_first_staff_in_improper_parentage_of_component.get_first_staff_in_improper_parentage_of_component
